% Script to launch a NMR experiment in my framework
%
% (c) Matthieu Guerquin-Kern, 2007.10.25

clear all;
%% Experimental settings

% Excitation
dataexc.B0 = 1.5;               % static magnetic field magnitude
dataexc.gamma = 2.678*1e8;      % gyroscopic ratio
dataexc.B1 = 0.07;              % excitation field magnitude
%dataexc.omega = dataexc.gamma*(dataexc.B0+0.1*dataexc.B1)                  % excitation frequency (resonance if not precised)
dataexc.M0  = [0;0;1];          % initial magnetization direction (will be normalized)
%dataexc.Texc = 200e-9;                   % duration of the excitation (depend on flip angle)
dataexc.Theta = pi/2;           % flip angle in radian (fixes the duration of excitation)
dataexc.Nt = 1e3;               % number of time samples

% Relaxation
datarel.B0 = 1.5;               % static magnetic field magnitude
datarel.gamma = 2.678*1e8;      % gyroscopic ratio
datarel.M0  = [1;0;0];          % initial magnetization (vector)
datarel.T1 = 30e-9;                 % T1 time constant (parallel relaxation)
datarel.T2 = 6e-9;               % T2 time constant (transverse relaxation)
datarel.Trel = 100e-9;               % duration of the observation (3*T1 by default)
datarel.Nt = 5e3;               % number of time samples

%% What we want to plot

plot.threeD = true;             % to display the 3D track
plot.X = true;                 % to display the magnetization along X axis
plot.Y = false;                 % to display the magnetization along Y axis
plot.XY = false;                % to display the magnetization component in plane XY
plot.Z = false;                 % to display the magnetization along Z axis
plot.save = true;              % to save the displayed graphs into pictures (or video)
plot.video = false;             % to display the graphs as videos

%% Simulation
M = [];
t = [];

[Mexc,texc] = NMRexc(dataexc);
M = [M Mexc];
t = [t texc];
%datarel.M0 = Mexc(:,end);
%[Mrel,trel] = NMRrel(datarel);
% M = [Mrel];
% t = [trel];
% 
%M = [M Mrel];
%t = [t t(end)+trel];


%% Plots
PlotNMRexp(M,t,plot)